"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGreaterThan = void 0;
const core_1 = require("@serenity-js/core");
/**
 * Creates an {@apilink Expectation|expectation} that is met when the actual value of type `number`
 * is greater than the expected `number`.
 *
 * ## Ensuring that a given number is greater than the expected number
 *
 * ```ts
 * import { actorCalled } from '@serenity-js/core'
 * import { Ensure, isGreaterThan } from '@serenity-js/assertions'
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that(10, isGreaterThan(5)),
 * )
 * ```
 *
 * ## Ensuring that a given number is within the expected range
 *
 * ```ts
 * import { actorCalled, Expectation, d } from '@serenity-js/core'
 * import { Ensure, and, equals, isGreaterThan, isLessThan, or } from '@serenity-js/assertions'
 *
 * const isWithinRange = (lowerBound: Answerable<number>, upperBound: Answerable<number>) =>
 *   Expectation.to(d`have value that is between ${ lowerBound } and ${ upperBound }`)
 *     .soThatActual(
 *       and(
 *         or(equals(lowerBound), isGreaterThan(lowerBound)),
 *         or(equals(upperBound), isLessThan(upperBound)),
 *       )
 *     ),
 *
 * await actorCalled('Ester').attemptsTo(
 *   Ensure.that(
 *     7,
 *     isWithinRange(5, 10)
 *   ),
 * )
 * ```
 *
 * @param expected
 *
 * @group Expectations
 */
exports.isGreaterThan = core_1.Expectation.define('isGreaterThan', 'have value greater than', (actual, expected) => actual > expected);
//# sourceMappingURL=isGreaterThan.js.map